==> qtjambi-serialbus-debuginfo-macos-5.15.20.jar: sources/QtJambiSerialBus/QCanBusDevice_shell.h <==
#ifndef QCANBUSDEVICE_SHELL_H
#define QCANBUSDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSerialBus/qcanbusdevice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <QtSerialBus/qcanbusframe.h>
#include <QtJambi/RegistryAPI>


class QCanBusDevice_shell : public QCanBusDevice, public QtJambiShellInterface
{
public:
    QCanBusDevice_shell(QObject* parent0 = nullptr);
    ~QCanBusDevice_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString interpretErrorFrame(const QCanBusFrame& errorFrame0) override;
    bool open() override;
    void setConfigurationParameter(int key0, const QVariant& value1) override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForFramesReceived(int msecs0) override;
    bool waitForFramesWritten(int msecs0) override;
    bool writeFrame(const QCanBusFrame& frame0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCanBusDevice_access : public QCanBusDevice
{
    void __qt_clearError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static jobject __qt_createDeviceInfo_cref_QString_cref_QString_cref_QString_int_bool_bool(JNIEnv *__jni_env, jstring name0, jstring serialNumber1, jstring description2, jint channel3, jboolean isVirtual4, jboolean isFlexibleDataRateCapable5);
    static jobject __qt_createDeviceInfo_cref_QString_bool_bool(JNIEnv *__jni_env, jstring name0, jboolean isVirtual1, jboolean isFlexibleDataRateCapable2);
    jobject __qt_dequeueOutgoingFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_enqueueOutgoingFrame_cref_QCanBusFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newFrame0);
    void __qt_enqueueReceivedFrames_cref_QVector(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject newFrames0);
    jboolean __qt_hasOutgoingFrames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCanBusStatusGetter_QCanBusDevice_CanBusStatusGetter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject busStatusGetter0);
    void __qt_setError_cref_QString_QCanBusDevice_CanBusError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring errorText0, jint arg__2);
    void __qt_setResetControllerFunction_QCanBusDevice_ResetControllerFunction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject resetter0);
    void __qt_setState_QCanBusDevice_CanBusDeviceState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_interpretErrorFrame_cref_QCanBusFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID errorFrame0);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setConfigurationParameter_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint key0, jobject value1);
    jboolean __qt_waitForFramesReceived_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForFramesWritten_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_writeFrame_cref_QCanBusFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID frame0);
};

#endif // QCANBUSDEVICE_SHELL_H

==> qtjambi-serialbus-debuginfo-macos-6.5.3.jar: sources/QtJambiSerialBus/QCanBusDevice_shell.h <==
#ifndef QCANBUSDEVICE_SHELL_H
#define QCANBUSDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSerialBus/qcanbusdevice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <QtSerialBus/qcanbusframe.h>
#include <QtJambi/RegistryAPI>


class QCanBusDevice_shell : public QCanBusDevice, public QtJambiShellInterface
{
public:
    QCanBusDevice_shell(QObject* parent0 = nullptr);
    ~QCanBusDevice_shell() override;

    QCanBusDevice::CanBusStatus busStatus() override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QCanBusDeviceInfo deviceInfo() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasBusStatus() const override;
    QString interpretErrorFrame(const QCanBusFrame& errorFrame0) override;
    bool open() override;
    void resetController() override;
    void setConfigurationParameter(QCanBusDevice::ConfigurationKey key0, const QVariant& value1) override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForFramesReceived(int msecs0) override;
    bool waitForFramesWritten(int msecs0) override;
    bool writeFrame(const QCanBusFrame& frame0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCanBusDevice_access : public QCanBusDevice
{
    void __qt_clearError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static jobject __qt_createDeviceInfo_cref_QString_cref_QString_bool_bool(JNIEnv *__jni_env, jstring plugin0, jstring name1, jboolean isVirtual2, jboolean isFlexibleDataRateCapable3);
    static jobject __qt_createDeviceInfo_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString_int_bool_bool(JNIEnv *__jni_env, jstring plugin0, jstring name1, jstring serialNumber2, jstring description3, jstring alias4, jint channel5, jboolean isVirtual6, jboolean isFlexibleDataRateCapable7);
    jobject __qt_dequeueOutgoingFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_enqueueOutgoingFrame_cref_QCanBusFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newFrame0);
    void __qt_enqueueReceivedFrames_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject newFrames0);
    jboolean __qt_hasOutgoingFrames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setError_cref_QString_QCanBusDevice_CanBusError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring errorText0, jint arg__2);
    void __qt_setState_QCanBusDevice_CanBusDeviceState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0);
    jint __qt_busStatus(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_deviceInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasBusStatus(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_interpretErrorFrame_cref_QCanBusFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID errorFrame0);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_resetController(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setConfigurationParameter_QCanBusDevice_ConfigurationKey_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint key0, jobject value1);
    jboolean __qt_waitForFramesReceived_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForFramesWritten_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_writeFrame_cref_QCanBusFrame(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID frame0);
};

#endif // QCANBUSDEVICE_SHELL_H
